==> branch-0.8.tar.gz: hadoop/src/test/org/apache/hadoop/dfs/TestDFSMkdirs.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.dfs;

import junit.framework.TestCase;
import java.io.*;
import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.fs.FileSystem;
import org.apache.hadoop.fs.Path;


/**
 * This class tests that the DFS command mkdirs cannot create subdirectories
 * from a file when passed an illegal path.  HADOOP-281.
 * @author Wendy Chien
 */
public class TestDFSMkdirs extends TestCase {

  private void writeFile(FileSystem fileSys, Path name) throws IOException {
    DataOutputStream stm = fileSys.create(name);
    stm.writeBytes("wchien");
    stm.close();
  }
  
  /**
   * Tests mkdirs can create a directory that does not exist and will
   * not create a subdirectory off a file.
   */
  public void testDFSMkdirs() throws IOException {
    Configuration conf = new Configuration();
    MiniDFSCluster cluster = new MiniDFSCluster(65312, conf, false);
    FileSystem fileSys = cluster.getFileSystem();
    try {
    	// First create a new directory with mkdirs
    	Path myPath = new Path("/test/mkdirs");
    	assertTrue(fileSys.mkdirs(myPath));
    	assertTrue(fileSys.exists(myPath));
    	assertTrue(fileSys.mkdirs(myPath));

    	// Second, create a file in that directory.
    	Path myFile = new Path("/test/mkdirs/myFile");
    	writeFile(fileSys, myFile);
   
    	// Third, use mkdir to create a subdirectory off of that file,
    	// and check that it fails.
    	Path myIllegalPath = new Path("/test/mkdirs/myFile/subdir");
        Boolean exist = true;
        try {
    	    fileSys.mkdirs(myIllegalPath);
        } catch (IOException e) {
            exist = false;
        }
    	assertFalse(exist);
    	assertFalse(fileSys.exists(myIllegalPath));
    	fileSys.delete(myFile);
    	
    } finally {
      fileSys.close();
      cluster.shutdown();
    }
  }
}

==> branch-0.11.tar.gz: hadoop/src/test/org/apache/hadoop/dfs/TestDFSMkdirs.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.dfs;

import junit.framework.TestCase;
import java.io.*;
import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.fs.FileSystem;
import org.apache.hadoop.fs.Path;


/**
 * This class tests that the DFS command mkdirs cannot create subdirectories
 * from a file when passed an illegal path.  HADOOP-281.
 * @author Wendy Chien
 */
public class TestDFSMkdirs extends TestCase {

  private void writeFile(FileSystem fileSys, Path name) throws IOException {
    DataOutputStream stm = fileSys.create(name);
    stm.writeBytes("wchien");
    stm.close();
  }
  
  /**
   * Tests mkdirs can create a directory that does not exist and will
   * not create a subdirectory off a file.
   */
  public void testDFSMkdirs() throws IOException {
    Configuration conf = new Configuration();
    MiniDFSCluster cluster = new MiniDFSCluster(65312, conf, 2, false);
    FileSystem fileSys = cluster.getFileSystem();
    try {
    	// First create a new directory with mkdirs
    	Path myPath = new Path("/test/mkdirs");
    	assertTrue(fileSys.mkdirs(myPath));
    	assertTrue(fileSys.exists(myPath));
    	assertTrue(fileSys.mkdirs(myPath));

    	// Second, create a file in that directory.
    	Path myFile = new Path("/test/mkdirs/myFile");
    	writeFile(fileSys, myFile);
   
    	// Third, use mkdir to create a subdirectory off of that file,
    	// and check that it fails.
    	Path myIllegalPath = new Path("/test/mkdirs/myFile/subdir");
        Boolean exist = true;
        try {
    	    fileSys.mkdirs(myIllegalPath);
        } catch (IOException e) {
            exist = false;
        }
    	assertFalse(exist);
    	assertFalse(fileSys.exists(myIllegalPath));
    	fileSys.delete(myFile);
    	
    } finally {
      fileSys.close();
      cluster.shutdown();
    }
  }
}
